@@ -95,7 +95,8 @@ Timezones::Timezones()
         exit(1);
     }
 
-    for (const auto &line : QString::fromUtf8(zoneTab.readAll()).split(QLatin1Char('\n'))) {
+    const auto lines = QString::fromUtf8(zoneTab.readAll()).split(QLatin1Char('\n'));
+    for (const auto &line : lines) {
         if (line.startsWith(QLatin1Char('#'))) {
             continue;
         }
@@ -122,7 +123,7 @@ Timezones::Timezones()
 
 Timezones::~Timezones() = default;
 
-QByteArray Timezones::timezoneForLocation(const QString &isoCode, const KnowledgeDb::Coordinate &coord) const
+QByteArray Timezones::timezoneForLocation(const QString &isoCode, KnowledgeDb::Coordinate coord) const
 {
     // look up by country
     QSet<QByteArray> countryTzs;
@@ -193,7 +194,7 @@ uint16_t Timezones::offset(const QByteArray& tz) const
     return m_zoneOffsets[std::distance(m_zones.begin(), it)];
 }
 
-QPoint Timezones::coordinateToPixel(const KnowledgeDb::Coordinate &coord) const
+QPoint Timezones::coordinateToPixel(KnowledgeDb::Coordinate coord) const
 {
     QPoint p;
     p.setX(qRound((coord.longitude - m_topLeftMapUnitX) / m_xMapUnitsPerPixel));
