@@ -56,7 +56,7 @@ void PdfExtractorOutputDevice::drawImage(GfxState* state, Object* ref, Stream* s
     pdfImg.d->m_refNum = ref->getRef().num;
     pdfImg.d->m_refGen = ref->getRef().gen;
 
-#ifdef HAVE_POPPLER_0_69
+#if KPOPPLER_VERSION >= QT_VERSION_CHECK(0, 69, 0)
     pdfImg.d->m_colorMap.reset(colorMap->copy());
 #endif
     pdfImg.d->m_sourceHeight = height;
@@ -168,7 +168,7 @@ void PdfExtractorOutputDevice::finalize()
             mergedOps.push_back(*it);
         }
     }
-    qDebug() << m_vectorOps.size() << mergedOps.size();
+    //qDebug() << m_vectorOps.size() << mergedOps.size();
 
     std::vector<PdfVectorPicture::PathStroke> strokes;
     QTransform t;
@@ -178,7 +178,7 @@ void PdfExtractorOutputDevice::finalize()
                 t = op.transform;
             }
             if (t != op.transform) {
-                qDebug() << "diffent transforms for strokes, not supported yet";
+                //qDebug() << "diffent transforms for strokes, not supported yet";
                 continue;
             }
             strokes.push_back(op.stroke);
